@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.76.2.4 2004/06/30 09:03:13 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.76.2.7 2004/11/24 00:01:28 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -98,9 +98,12 @@
 #define OCHUSHA_DEFAULT_CAPACITY_OF_IMAGE_CACHE		32
 #define OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_CACHE_FILES	256
 
+#define OCHUSHA_DEFAULT_AALIST_FILENAME			"aalist.txt"
+#define OCHUSHA_DEFAULT_AALIST_CHAR_ENCODING		"UTF-8"
+#define OCHUSHA_DEFAULT_FOCUS_FOLLOW_MOUSE		FALSE
 
-#define THREAD_VIEW_EXTRA_WIDTH			30
-#define POPUP_MARGIN_HEIGHT			10
+#define THREAD_VIEW_EXTRA_WIDTH				30
+#define POPUP_MARGIN_HEIGHT				5
 
 #define OCHUSHA_MINIMIZED_ICON			"Ochusha-Minimized"
 
@@ -304,6 +307,13 @@ struct _OchushaApplication
   /* ǸΥɥǥ쥯ȥ */
   char *last_download_directory;
 
+  /* AAϻٱ */
+  char *aalist_filename;
+  char *aalist_char_encoding;
+
+  /* ޥݥ󥿤ΰ֤ǥեѹ */
+  gboolean focus_follow_mouse;
+
   /* ˽λɤ */
   gboolean shutdown_succeeded;
   gboolean recover_mode;
@@ -334,6 +344,13 @@ struct _OchushaApplication
   gboolean dolib_login_at_startup;
   gboolean dolib_use_id_for_posting;
 
+
+  /* 2ch BeϢ */
+  char *be_id;
+  char *be_passwd;
+  gboolean be_save_passwd;
+  gboolean be_login_at_startup;
+
   OchushaConfig config;
 };
 
