@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: regex_utils.h,v 1.3 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: regex_utils.h,v 1.3.2.1 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _REGEX_UTILS_H_
@@ -66,7 +66,7 @@ struct _RegexEditorClass
 };
 
 
-GType regex_editor_get_type(void);
+GType regex_editor_get_type(void) G_GNUC_CONST;
 GtkWidget *regex_editor_new(const gchar *regex_text);
 void regex_editor_set_regex_text(RegexEditor *editor, const gchar *text);
 gchar *regex_editor_get_regex_text(RegexEditor *editor);
