@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.45.2.4 2004/09/22 14:31:28 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.45.2.7 2004/12/29 06:59:08 fuyu Exp $
  */
 
 #include "config.h"
@@ -365,6 +365,7 @@ ochusha_board_2ch_get_subject_txt_encoding(OchushaBulletinBoard *board)
       return "CP932";
 
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       return "EUC-JP";
 
     default:
@@ -693,6 +694,7 @@ ochusha_board_2ch_get_response_character_encoding(OchushaBulletinBoard *board)
       return "CP932";
 
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       return "EUC-JP";
 
     default:
@@ -713,6 +715,10 @@ ochusha_board_2ch_get_response_iconv_helper(OchushaBulletinBoard *board)
     case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
       return cp932_to_utf8_helper;
 
+    case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
+      return eucjp_to_utf8_helper;
+
     default:
       return NULL;
     }
@@ -728,6 +734,7 @@ ochusha_board_2ch_is_new_thread_supported(OchushaBulletinBoard *board)
     {
     case OCHUSHA_BBS_TYPE_2CH:
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       return TRUE;
 
     case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
@@ -769,6 +776,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
     {
     case OCHUSHA_BBS_TYPE_2CH:
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       break;
 
     case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
@@ -838,6 +846,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
       break;
 
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&time=%ld", title, from, mail, message, bbs, time);
       break;
 
@@ -845,11 +854,11 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
       goto error_exit;
     }
 
-  post_result = ochusha_utils_2ch_try_post(broker, board, query);
+  post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       sleep(10);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query);
+      post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
     }
 
 #if 0
@@ -857,7 +866,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query);
+      post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
     }
 #endif
   if (post_result != OCHUSHA_UTILS_2CH_POST_SUCCESS)
@@ -938,6 +947,7 @@ ochusha_board_2ch_get_read_cgi_url(OchushaBoard2ch *board_2ch)
 	case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
 	case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
 	case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+	case OCHUSHA_BBS_TYPE_2CH_BE:
 	  if (snprintf(url, PATH_MAX, "http://%s/test/read.cgi",
 		       ochusha_bulletin_board_get_server(board)) < PATH_MAX)
 	    board_2ch->read_cgi_url = G_STRDUP(url);
@@ -1111,7 +1121,15 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = cp932_to_utf8_helper;
       break;
 
+    case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
+      converter_helper = eucjp_to_utf8_helper;
+      break;
+
     default:
+      fprintf(stderr,
+	      "Warning: helper function for iconv not specified for: %s\n",
+	      ochusha_bulletin_board_get_base_url(board));
       converter_helper = NULL;
     }
 
