@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.17.2.2 2004/06/16 05:25:10 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.17.2.5 2004/11/25 08:59:45 fuyu Exp $
  */
 
 #include "config.h"
@@ -352,6 +352,8 @@ ochusha_board_jbbs_get_response_iconv_helper(OchushaBulletinBoard *board)
 
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
     case OCHUSHA_BBS_TYPE_MITINOKU:
+      return eucjp_to_utf8_helper;
+
     default:
       return NULL;
     }
@@ -743,6 +745,11 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = cp932_to_utf8_helper;
       break;
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+    case OCHUSHA_BBS_TYPE_MITINOKU:
+      converter_helper = eucjp_to_utf8_helper;
+      break;
+
     default:
       converter_helper = NULL;
     }
@@ -855,9 +862,17 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 #if 1	/* 쥿äƤޤäĶ */
 	    else
 	      {
+#if 0
+		char *tmp_title = G_STRNDUP(title_pos, title_len);
+		fprintf(stderr, "orig title: \"%s\"\n", tmp_title);
+		G_FREE(tmp_title);
+#endif
 		thread_title = simple_string_canon(title_pos, title_len,
 						   converter,
 						   converter_helper);
+#if 0
+		fprintf(stderr, "title: \"%s\"\n", thread_title);
+#endif
 		ochusha_bbs_thread_set_title(thread, thread_title);
 		G_FREE(thread_title);
 	      }
@@ -1051,7 +1066,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MITINOKU:
-      converter_helper = NULL;
+      converter_helper = eucjp_to_utf8_helper;
       if (regcomp(&threadlist_entry_pattern,
 		  ".*</a>:<a href=.*key=([1-9][0-9]*)[^>]*>(.*)&lt;([1-9][0-9]*)&gt;</a><br>$", REG_EXTENDED))
 	{
@@ -1062,10 +1077,13 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 
     case OCHUSHA_BBS_TYPE_MACHIBBS:
     case OCHUSHA_BBS_TYPE_JBBS:
-    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
     default:
       converter_helper = cp932_to_utf8_helper;
       return FALSE;	/* ̤ݡ */
+
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      converter_helper = eucjp_to_utf8_helper;
+      return FALSE;	/* ̤ݡ */
     }
 
   converter = iconv_open("UTF-8//IGNORE",
@@ -1121,7 +1139,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 
 	    if (html_line == NULL
 		|| regexec(&threadlist_entry_pattern,
-			   html_line, 3, match, 0) != 0)
+			   html_line, 4, match, 0) != 0)
 	      {
 #if 0
 		fprintf(stderr, "html_line: \"%s\"\n", html_line);
