@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.38.2.3 2004/12/29 06:58:28 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.38.2.4 2004/12/30 14:16:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -293,10 +293,7 @@ extract_jbbs_response(char *start_pos, char *eol_pos,
    *
    * ǶDATɤ߹褦ˤʤäJBBSФʷǼĤξ硢
    * ֹ<>ᥤ<><>쥹<>[åɥȥ]<>[ۥorID]
-   * ȤˤʤäƤ롣
-   *
-   * ᤤˤη򥵥ݡȤޤBBSʤɤǹƤDATե
-   * ηѹͽ2chΤޤޤˤʤäƤ롣
+   * ȤˤʤäƤ롣̯ѤäϤʤΤץå
    */
   char *clone_buffer = NULL;
   char *cur_pos = start_pos;
@@ -855,11 +852,12 @@ ochusha_thread_jbbs_get_url_for_response(OchushaBBSThread *thread, int from,
       {
 	if (from >= to)
 	  to = from;
-	snprintf(url, PATH_MAX, "http://%s%sbbs/read.cgi?BBS=%s&KEY=%s&START=%d&END=%d&NOFIRST=TRUE",
-		 ochusha_bulletin_board_get_server(thread->board),
-		 ochusha_bulletin_board_get_base_path(thread->board),
-		 ochusha_bulletin_board_get_id(thread->board),
-		 thread->id, from, to);
+	if (to == from)
+	  snprintf(url, PATH_MAX, "%s%d",
+		   ochusha_bbs_thread_get_url(thread), from);
+	else
+	  snprintf(url, PATH_MAX, "%s%d-%d",
+		   ochusha_bbs_thread_get_url(thread), from, to);
 	break;
       }
 
@@ -896,13 +894,16 @@ ochusha_thread_jbbs_get_url_to_post(OchushaBBSThread *thread)
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
       snprintf(url, PATH_MAX, "%s?BBS=%s&KEY=%s&LAST=10",
 	       ochusha_board_2ch_get_read_cgi_url(OCHUSHA_BOARD_2CH(thread->board)),
 	       ochusha_bulletin_board_get_id(thread->board),
 	       thread->id);
       break;
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      snprintf(url, PATH_MAX, "%sl10", ochusha_bbs_thread_get_url(thread));
+      break;
+
     case OCHUSHA_BBS_TYPE_MITINOKU:
       snprintf(url, PATH_MAX, "%s?bbs=%s&key=%s&ls=10",
 	       ochusha_board_2ch_get_read_cgi_url(OCHUSHA_BOARD_2CH(thread->board)),
@@ -1628,7 +1629,7 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
   const char *fake_dat_url = ochusha_thread_2ch_get_dat_url(thread_2ch);
   WorkerJob *job;
   HTML2DATConverterJobArgs *args;
-  int incoming_offset = 0;
+  int incoming_offset;
   int number_of_cached_responses = 0;
   char cgi_url[PATH_MAX];
 
@@ -1646,6 +1647,9 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 
   if (mode != OCHUSHA_NETWORK_BROKER_CACHE_IGNORE)
     {
+      if (buffer != NULL)
+	incoming_offset = buffer->length;
+
       if (buffer == NULL || !ochusha_async_buffer_reset(buffer))
 	{
 	  int fd = ochusha_config_cache_open_file(broker->config, fake_dat_url,
@@ -1671,11 +1675,13 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 		}
 	      close(fd);
 	    }
+	  else
+	    incoming_offset = 0;
 	}
       else
 	{
 	  dat_buffer = buffer;
-	  incoming_offset = buffer->length;
+	  ochusha_async_buffer_update_length(dat_buffer, incoming_offset);
 	}
 
       /* ¸Υ쥹 */
@@ -1708,11 +1714,9 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
       break;
 
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
-      if (snprintf(cgi_url, PATH_MAX, "http://%s/bbs/read.cgi%s%s/%s/%d-",
-		   ochusha_bulletin_board_get_server(thread->board),
-		   ochusha_bulletin_board_get_base_path(thread->board),
-		   ochusha_bulletin_board_get_id(thread->board),
-		   thread->id, number_of_cached_responses + 1) >= PATH_MAX)
+      if (snprintf(cgi_url, PATH_MAX, "%s%d-",
+		   ochusha_bbs_thread_get_url(thread),
+		   number_of_cached_responses + 1) >= PATH_MAX)
 	cgi_url[0] = '\0';
       break;
 
