@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.12 2004/12/29 06:59:08 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.13 2004/12/30 14:15:50 fuyu Exp $
  */
 
 #include "config.h"
@@ -1104,6 +1104,15 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 	snprintf(cookie_buf, 4096, "%s", broker->config->session_id_2ch_be);
       cookie = cookie_buf;
     }
+  else if (board->bbs_type == OCHUSHA_BBS_TYPE_2CH
+	   && cookie != NULL
+	   && broker->config->use_2ch_be_id_for_2ch
+	   && broker->config->session_id_2ch_be != NULL)
+    {
+      snprintf(cookie_buf, 4096, "%s %s ;",
+	       broker->config->session_id_2ch_be, cookie);
+      cookie = cookie_buf;
+    }
   post_result = ochusha_network_broker_try_post(broker, url,
 				ochusha_bulletin_board_get_server(board),
 				ochusha_bulletin_board_get_base_url(board),
@@ -1423,7 +1432,6 @@ ochusha_utils_2ch_be_login(OchushaConfig *config, OchushaNetworkBroker *broker,
   server = ochusha_utils_url_extract_http_server(config->login_2ch_be_url);
   g_return_if_fail(server != NULL);
 
-#if 1
   id = ochusha_utils_url_encode_string(user_id);
   g_return_if_fail(id != NULL);
 
@@ -1434,10 +1442,6 @@ ochusha_utils_2ch_be_login(OchushaConfig *config, OchushaNetworkBroker *broker,
 
   G_FREE(id);
   G_FREE(pw);
-#else
-  snprintf(content_body, 4096,
-	   "submit=%%C5%%D0%%CF%%BF&m=%s&p=%s", user_id, passwd);
-#endif
   post_result = ochusha_network_broker_try_post(broker,
 						config->login_2ch_be_url,
 						server,
