@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.h,v 1.13.2.3 2004/12/29 06:59:08 fuyu Exp $
+ * $Id: utils.h,v 1.13.2.4 2004/12/30 16:58:47 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -66,7 +66,7 @@ char *ochusha_utils_url_extract_http_absolute_path(const char *url);
 char *ochusha_utils_url_encode_string(const char *src);
 char *ochusha_utils_url_decode_string(const char *src);
 
-char *ochusha_utils_javascript_extract_url(const char *url);
+char *ochusha_utils_hack_known_special_url(const char *url);
 
 time_t ochusha_utils_get_utc_time(const char *date_string);
 
