@@ -2,7 +2,7 @@
 
   regint.h -  Oniguruma (regular expression library)
 
-  Copyright (C) 2002-2004  K.Kosako (kosako@sofnec.co.jp)
+  Copyright (C) 2002-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
 
 **********************************************************************/
 #ifndef REGINT_H
@@ -117,7 +117,9 @@
 #endif
 
 #include <ctype.h>
+#ifndef __BORLANDC__
 #include <sys/types.h>
+#endif
 
 #ifdef ONIG_DEBUG
 # include <stdio.h>
@@ -300,6 +302,8 @@ typedef unsigned int  BitStatusType;
 /* ignore-case and multibyte status are included in compiled code. */
 #define IS_DYNAMIC_OPTION(option)  0
 
+#define REPEAT_INFINITE         -1
+#define IS_REPEAT_INFINITE(n)   ((n) == REPEAT_INFINITE)
 
 /* bitset */
 #define BITS_PER_BYTE      8
